import React, { useState } from "react";
import { useNavigate } from "react-router-dom"; // Use useNavigate instead
import "./AdminHome.css";
import axios from "axios";

function AdminHome() {
  const navigate = useNavigate(); // Initialize useNavigate hook
  const [isSidebarOpen, setSidebarOpen] = useState(true);
  const [viewingUsers, setViewingUsers] = useState(false);
  const [firstName, setFirstName] = useState("");  // State for first name input
  const [lastName, setLastName] = useState("");   // State for last name input
  const [editingUser, setEditingUser] = useState(null);
  const [userData, setUserData] = useState({ name: "", email: "" });
  const [middleName, setMiddleName] = useState("");
  const [suffix, setSuffix] = useState("");
  const [maidenName, setMaidenName] = useState("");
  const [nickname, setNickname] = useState("");
  const [gender, setGender] = useState("");
  const [techAlumChapter, setTechAlumChapter] = useState("");
  const [classYear, setClassYear] = useState("");
  const [gradYear, setGradYear] = useState("");
  const [gradSemester, setGradSemester] = useState("");
  const [subject, setSubject] = useState("");
  const [degreeType, setDegreeType] = useState("");
  const [degreeYear, setDegreeYear] = useState("");
  const [degreeDescription, setDegreeDescription] = useState("");
  const [degreeDepartment, setDegreeDepartment] = useState("");
  const [degreeCollege, setDegreeCollege] = useState("");
  const [address1, setAddress1] = useState("");
  const [address2, setAddress2] = useState("");
  const [city, setCity] = useState("");
  const [state, setState] = useState("");
  const [country, setCountry] = useState("");
  const [zipCode, setZipCode] = useState("");
  const [preferredAddress, setPreferredAddress] = useState(false);
  const [contactNumber, setContactNumber] = useState("");
  const [contactType, setContactType] = useState("");
  const [preferredContact, setPreferredContact] = useState(false);
  const [involvements, setInvolvements] = useState("");

  const toggleSidebar = () => {
    setSidebarOpen(!isSidebarOpen);
  };

  const handleViewUsersClick = () => {
    setViewingUsers(true);
  };

  const handleBackClick = () => {
    setViewingUsers(false);
    setEditingUser(null);
  };

  const handleCreateUser = () => {
    window.location.href = "/MyAccountAdminView";
  };
  

  const handleSearchSubmit = async (e) => {
    e.preventDefault();
  
    // Prepare the data object using all useStates
    const data = JSON.stringify({
      firstName,
      lastName,
      middleName,
      suffix,
      maidenName,
      nickname,
      gender,
      techAlumChapter,
      classYear,
      gradYear,
      gradSemester,
      subject,
      degreeType,
      degreeYear,
      degreeDescription,
      degreeDepartment,
      degreeCollege,
      address1,
      address2,
      city,
      state,
      country,
      zipCode,
      preferredAddress,
      contactNumber,
      contactType,
      preferredContact,
      involvements,
    });
    
    try {
      const config = {
        method: 'post',
        maxBodyLength: Infinity,
        url: `${process.env.REACT_APP_API_URL}./components/SearchResults/SearchResults`,
        headers: { 
          'Content-Type': 'application/json',
        },
        data: data,
      };
  
      const response = await axios.request(config);
      console.log(JSON.stringify(response.data));
      
      // Use navigate to redirect or update state with response data if needed
      navigate("/search-results", { state: { users: response.data } });
    } catch (error) {
      console.error(error);
    }
  
    // Reset the input fields after submission if desired
    setFirstName("");
    setLastName("");
    setMiddleName("");
    setSuffix("");
    setMaidenName("");
    setNickname("");
    setGender("");
    setTechAlumChapter("");
    setClassYear("");
    setGradYear("");
    setGradSemester("");
    setSubject("");
    setDegreeType("");
    setDegreeYear("");
    setDegreeDescription("");
    setDegreeDepartment("");
    setDegreeCollege("");
    setAddress1("");
    setAddress2("");
    setCity("");
    setState("");
    setCountry("");
    setZipCode("");
    setPreferredAddress(false);
    setContactNumber("");
    setContactType("");
    setPreferredContact(false);
    setInvolvements("");
  };
  
  

  const handleUpdateSubmit = async (e) => {
    e.preventDefault();
  
    // Prepare the data object using all useStates
    const data = JSON.stringify({
      personInfo: {
        peopleId: editingUser, // Assuming editingUser holds the ID of the user being edited
        firstName,
        lastName,
        middleName,
        maidenName,
        suffix,
        nickName: nickname,
        techAlumniChapter: techAlumChapter,
        classYear,
        gradYear,
        gradSemester,
        gender,
      },
      degrees: [
        {
          peopleDegreeId: 1, // Example ID, you may want to manage this based on actual user data
          degreeType, // Assuming you handle multiple degrees, this might need to be part of a state array
          degreeDepartment,
          degreeCollege,
          degreeYear,
          degreeDescription,
        },
        
      ],
      addresses: [
        {
          addressId: 1, // Example ID, similar to degrees, manage based on user data
          address1,
          address2,
          city,
          state,
          country,
          zipCode,
          preferredAddress: preferredAddress ? "1" : "0", // Adjust to match API expectations
        },
  
      ],
      contacts: [], // Add contacts from the state if necessary
      involvements: involvements.split(","), // Assuming involvements is a comma-separated string
    });
  
    try {
      const config = {
        method: 'put',
        maxBodyLength: Infinity,
        url: `${process.env.REACT_APP_API_URL}./components/SearchResults/SearchResults`, // Dynamic URL based on user ID
        headers: {
          'Content-Type': 'application/json',
        },
        data: data,
      };
  
      const response = await axios.request(config);
      console.log(JSON.stringify(response.data));
      
      // Optionally navigate or update state after the update
      navigate("/search-results", { state: { updatedUser: response.data } });
    } catch (error) {
      console.error("Error updating user:", error);
    }
  };
  
  

  return (
    <div className="admin-page">
      {/* Navbar */}
      {/* <nav className="navbar">
        <div className="navbar-links">
          <a href="#a">Home</a>
          <a href="#b">Browse</a>
          <a href="#c">Search</a>
          {/* <a href="#d">Messages</a> }
        </div>
      </nav> */}*/

      <div className="main-content">
        {/* Sidebar */}
        <div className={`sidebar ${isSidebarOpen ? "open" : "closed"}`}>
          <button className="sidebar-toggle" onClick={toggleSidebar}>
            {isSidebarOpen ? "←" : "→"}
          </button>
          {isSidebarOpen && (
            <ul className="sidebar-menu">
              <li><a href="#e">Account Settings</a></li>
              <li><a href="#f">Privacy Policy</a></li>
              <li><a href="#g">What the app does?</a></li>
              <li><a href="#g">How can you use this app?</a></li>
              <li><a href="#g">Cadet Mission Statement </a></li>
            </ul>
          )}
        </div>

        {/* Dashboard */}
        <div className="content">
          <h1>Welcome to Admin Page</h1>
          <div className="dashboard">
            {viewingUsers ? (
              <>
                <button className="back-button" onClick={handleBackClick}>
                  ← Back to Dashboard
                </button>

                <button onClick={handleCreateUser}>
                  Create New User
                </button>

                {/* Search by First Name and Last Name */}
                <form className="search-area" onSubmit={handleSearchSubmit}>
                  <input
                    type="text"
                    placeholder="First Name"
                    className="search-input"
                    value={firstName}
                    onChange={(e) => setFirstName(e.target.value)}
                  />
                  <input
                    type="text"
                    placeholder="Last Name"
                    className="search-input"
                    value={lastName}
                    onChange={(e) => setLastName(e.target.value)}
                  />
                  <input
                      type="text"
                      placeholder="Middle Name"
                      value={middleName}
                      onChange={(e) => setMiddleName(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Suffix"
                      value={suffix}
                      onChange={(e) => setSuffix(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Maiden Name"
                      value={maidenName}
                      onChange={(e) => setMaidenName(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Nickname"
                      value={nickname}
                      onChange={(e) => setNickname(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Gender"
                      value={gender}
                      onChange={(e) => setGender(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Tech Alum Chapter"
                      value={techAlumChapter}
                      onChange={(e) => setTechAlumChapter(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Class Year"
                      value={classYear}
                      onChange={(e) => setClassYear(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Graduation Year"
                      value={gradYear}
                      onChange={(e) => setGradYear(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Graduation Semester"
                      value={gradSemester}
                      onChange={(e) => setGradSemester(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Degree Subject"
                      value={subject}
                      onChange={(e) => setSubject(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Degree Type"
                      value={degreeType}
                      onChange={(e) => setDegreeType(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Degree Year"
                      value={degreeYear}
                      onChange={(e) => setDegreeYear(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Degree Description"
                      value={degreeDescription}
                      onChange={(e) => setDegreeDescription(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Degree Department"
                      value={degreeDepartment}
                      onChange={(e) => setDegreeDepartment(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Degree College"
                      value={degreeCollege}
                      onChange={(e) => setDegreeCollege(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Address Line 1"
                      value={address1}
                      onChange={(e) => setAddress1(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Address Line 2"
                      value={address2}
                      onChange={(e) => setAddress2(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="City"
                      value={city}
                      onChange={(e) => setCity(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="State"
                      value={state}
                      onChange={(e) => setState(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Country"
                      value={country}
                      onChange={(e) => setCountry(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Zip Code"
                      value={zipCode}
                      onChange={(e) => setZipCode(e.target.value)}
                    />
                    <label>
                      Preferred Address:
                      <input
                        type="checkbox"
                        checked={preferredAddress}
                        onChange={(e) => setPreferredAddress(e.target.checked)}
                      />
                    </label>
                    <input
                      type="text"
                      placeholder="Contact Number"
                      value={contactNumber}
                      onChange={(e) => setContactNumber(e.target.value)}
                    />
                    <input
                      type="text"
                      placeholder="Contact Type"
                      value={contactType}
                      onChange={(e) => setContactType(e.target.value)}
                    />
                    <label>
                      Preferred Contact:
                      <input
                        type="checkbox"
                        checked={preferredContact}
                        onChange={(e) => setPreferredContact(e.target.checked)}
                      />
                    </label>
                    <input
                      type="text"
                      placeholder="Involvements"
                      value={involvements}
                      onChange={(e) => setInvolvements(e.target.value)}
                    />

                  <button
                    type="submit"
                    className="search-button"
                  >
                    Submit
                  </button>

                  
                </form>
           
                
              </>
            ) : (
              <>
                <div className="dashboard-item" onClick={handleViewUsersClick}>
                  <span>View Users</span>
                </div>

                <div className="dashboard-item">
                  <input type="file" onChange={() => console.log("XLSX Uploaded")} />
                  <span>Upload XLSX</span>
                </div>
                <div className="dashboard-item" onClick={() => console.log("Tracking Page Visits")}>
                  <span>Track Application Activity</span>
                </div>
              </>
            )}
          </div>
        </div>
      </div>
    </div>
  );
}

export default AdminHome;
