import React, { useEffect, useState } from "react";
import { useParams } from "react-router-dom";
import axios from "axios";
import styles from "./EditUserDetailsStyles.module.css";

const EditUserDetails = () => {
  const { personId } = useParams();
  const [personDetails, setPersonDetails] = useState(null); 
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  // I added these two useStates so we will be able to check for editing and deleting
  const [isEditing, setIsEditing] = useState(false);
  const [showDeleteConfirm, setShowDeleteConfirm] = useState(false);
  // const navigate = useNavigate();

  useEffect(() => {
    const fetchPersonDetails = async () => {
      setLoading(true);
      setError(null);

      try {
        const response = await axios.get(
          `${process.env.REACT_APP_API_URL}/person/fullInfo/${personId}`
        );
        setPersonDetails(response.data.person);
      } catch (err) {
        setError(
          err.response?.data?.message || "Failed to fetch user details."
        );
      } finally {
        setLoading(false);
      }
    };

    fetchPersonDetails();
  }, [personId]);

  // const handleEdit = () => {
  //   setIsEditing(true);
  // };

  // const handleSave = async () => {
  //   try {
  //     await axios.put(
  //       `${process.env.REACT_APP_API_URL}/person/update/${personId}`,
  //       personDetails
  //     );
  //     setIsEditing(false);
  //     alert("User details updated successfully!");
  //   } catch (err) {
  //     alert("Failed to update user details.");
  //   }
  // };

  const handleEdit = () => {
    setIsEditing(true);
  };
  
  const handleSave = async () => {
    try {
      // Make sure to send a fresh copy of personDetails if it's being modified
      const updatedDetails = { ...personDetails };
      // Optionally update specific fields here if needed
      await axios.put(
        `${process.env.REACT_APP_API_URL}/person/update/${personId}`,
        updatedDetails
      );
      setIsEditing(false);
      alert("User details updated successfully!");
    } catch (err) {
      alert("Failed to update user details.");
    }
  };

  const handleDelete = async () => {
    try {
      await axios.delete(`${process.env.REACT_APP_API_URL}/person/${personId}`);
      alert("User deleted successfully!");
      // navigate("/users");
    } catch (err) {
      alert("Failed to delete user.");
    }
  };

  if (loading) return <p>Loading user details...</p>;
  if (error) return <p className={styles.error}>{error}</p>;

  return (
    <div className={styles.container}>
      <h2>User Details</h2>
      <p><strong>Person ID:</strong> {personId}</p>
      <div className={styles.details}>

        <p>
        <strong>First Name:</strong>{" "}
        {isEditing ? (
          <input
            type="text"
            value={personDetails.personalInformation.firstName}
            onChange={(e) =>
              setPersonDetails((prevDetails) => ({
                ...prevDetails,
                personalInformation: {
                  ...prevDetails.personalInformation,
                  firstName: e.target.value,
                },
              }))
            }
          />
        ) : (
          personDetails.personalInformation.firstName
        )}
      </p>
        <p>
          <strong>Last Name:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.lastName}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    lastName: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.lastName
          )}
        </p>
        <p>
          <strong>Middle Name:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.middleName || ""}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    middleName: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.middleName || "N/A"
          )}
        </p>
        <p>
          <strong>Nick Name:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.nickName || ""}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    nickName: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.nickName || "N/A"
          )}
        </p>
        <p>
          <strong>Class Year:</strong>{" "}
          {isEditing ? (
            <input
              type="number"
              value={personDetails.personalInformation.classYear}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    classYear: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.classYear
          )}
        </p>
        <p>
          <strong>Graduation Year:</strong>{" "}
          {isEditing ? (
            <input
              type="number"
              value={personDetails.personalInformation.gradYear}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    gradYear: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.gradYear
          )}
        </p>
        <p>
          <strong>Gender:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.gender}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    gender: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.gender
          )}
        </p>
        <p>
          <strong>Tech Alumni Chapter:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.techAlumniChapter}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    techAlumniChapter: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.techAlumniChapter
          )}
        </p>

        {/* Degrees Section */}
        <div>
          {personDetails.degreeInformation.map((degree, index) => (
            <div key={index}>
              {/* Degree Type */}
              <p>
                <strong>Degree Type:</strong>{" "}
                {isEditing ? (
                  <input
                    type="text"
                    value={degree.degreeType}
                    onChange={(e) => {
                      const updatedDegrees = [...personDetails.degreeInformation];
                      updatedDegrees[index].degreeType = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        degreeInformation: updatedDegrees,
                      });
                    }}
                  />
                ) : (
                  degree.degreeType
                )}
              </p>

              {/* Degree Department */}
              <p>
                <strong>Degree Department:</strong>{" "}
                {isEditing ? (
                  <input
                    type="text"
                    value={degree.degreeDepartment}
                    onChange={(e) => {
                      const updatedDegrees = [...personDetails.degreeInformation];
                      updatedDegrees[index].degreeDepartment = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        degreeInformation: updatedDegrees,
                      });
                    }}
                  />
                ) : (
                  degree.degreeDepartment
                )}
              </p>

              {/* Degree College */}
              <p>
                <strong>Degree College:</strong>{" "}
                {isEditing ? (
                  <input
                    type="text"
                    value={degree.degreeCollege}
                    onChange={(e) => {
                      const updatedDegrees = [...personDetails.degreeInformation];
                      updatedDegrees[index].degreeCollege = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        degreeInformation: updatedDegrees,
                      });
                    }}
                  />
                ) : (
                  degree.degreeCollege
                )}
              </p>

              {/* Degree Year */}
              <p>
                <strong>Degree Year:</strong>{" "}
                {isEditing ? (
                  <input
                    type="number"
                    value={degree.degreeYear}
                    onChange={(e) => {
                      const updatedDegrees = [...personDetails.degreeInformation];
                      updatedDegrees[index].degreeYear = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        degreeInformation: updatedDegrees,
                      });
                    }}
                  />
                ) : (
                  degree.degreeYear
                )}
              </p>

              {/* Degree Description */}
              <p>
                <strong>Degree Description:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={degree.degreeDescription}
                    onChange={(e) => {
                      const updatedDegrees = [...personDetails.degreeInformation];
                      updatedDegrees[index].degreeDescription = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        degreeInformation: updatedDegrees,
                      });
                    }}
                  />
                ) : (
                  degree.degreeDescription
                )}
              </p>
            </div>
          ))}
        </div>
        <div>
          {personDetails.addressInformation.map((address, index) => (
            <div key={index}>
              <p>
                <strong>Address1:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={address.address1}
                    onChange={(e) => {
                      const updatedAddress = [...personDetails.addressInformation];
                      updatedAddress[index].address1 = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        addressInformation: updatedAddress,
                      });
                    }}
                  />
                ) : (
                  address.address1
                )}
              </p>

              <p>
                <strong>Address2:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={address.address2}
                    onChange={(e) => {
                      const updatedAddress = [...personDetails.addressInformation];
                      updatedAddress[index].address2 = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        addressInformation: updatedAddress,
                      });
                    }}
                  />
                ) : (
                  address.address2
                )}
              </p>

              <p>
                <strong>City:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={address.city}
                    onChange={(e) => {
                      const updatedAddress = [...personDetails.addressInformation];
                      updatedAddress[index].city = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        addressInformation: updatedAddress,
                      });
                    }}
                  />
                ) : (
                  address.city
                )}
              </p>

              <p>
                <strong>State:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={address.state}
                    onChange={(e) => {
                      const updatedAddress = [...personDetails.addressInformation];
                      updatedAddress[index].state = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        addressInformation: updatedAddress,
                      });
                    }}
                  />
                ) : (
                  address.state
                )}
              </p>

              <p>
                <strong>Country:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={address.country}
                    onChange={(e) => {
                      const updatedAddress = [...personDetails.addressInformation];
                      updatedAddress[index].country = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        addressInformation: updatedAddress,
                      });
                    }}
                  />
                ) : (
                  address.country
                )}
              </p>

              <p>
                <strong>Zipcode:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={address.zipCode}
                    onChange={(e) => {
                      const updatedAddress = [...personDetails.addressInformation];
                      updatedAddress[index].zipCode = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        addressInformation: updatedAddress,
                      });
                    }}
                  />
                ) : (
                  address.zipCode
                )}
              </p>

              <p>
                <strong>Preferred Address:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={address.preferredAddress}
                    onChange={(e) => {
                      const updatedAddress = [...personDetails.addressInformation];
                      updatedAddress[index].preferredAddress = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        addressInformation: updatedAddress,
                      });
                    }}
                  />
                ) : (
                  address.preferredAddress
                )}
              </p>
            </div>
          ))}
        </div>

        <div>
          {personDetails.contactInformation.map((contact, index) => (
            <div key={index}>
              <p>
                <strong>Contact Type:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={contact.contactType}
                    onChange={(e) => {
                      const updatedContacts = [...personDetails.contactInformation];
                      updatedContacts[index].contactType = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        contactInformation: updatedContacts,
                      });
                    }}
                  />
                ) : (
                  contact.contactType
                )}
              </p>

              <p>
                <strong>Contact Number:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={contact.contactNumber}
                    onChange={(e) => {
                      const updatedContacts = [...personDetails.contactInformation];
                      updatedContacts[index].contactNumber = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        contactInformation: updatedContacts,
                      });
                    }}
                  />
                ) : (
                  contact.contactNumber
                )}
              </p>

              <p>
                <strong>Preferred Contact:</strong>{" "}
                {isEditing ? (
                  <textarea
                    value={contact.preferredContact}
                    onChange={(e) => {
                      const updatedContacts = [...personDetails.contactInformation];
                      updatedContacts[index].preferredContact = e.target.value;
                      setPersonDetails({
                        ...personDetails,
                        contactInformation: updatedContacts,
                      });
                    }}
                  />
                ) : (
                  contact.preferredContact
                )}
              </p>
            </div>
          ))}
        </div>

      
      <div>
          {personDetails.involvmentInformation.map((involvement, index) => (
            <div key={index}>
        <p>
          <strong>Involvements:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.involvmentInformation}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  involvmentInformation: {
                    ...personDetails.involvmentInformation,
                    involvements: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.involvements
          )}
        </p>
        
          </div>
          ))}
        </div>

        {!isEditing ? (
          <button className={styles.editButton} onClick={handleEdit}>
            Edit
          </button>
        ) : (
          <button className={styles.saveButton} onClick={handleSave}>
            Save
          </button>
        )}
        <button
          className={styles.deleteButton}
          onClick={() => setShowDeleteConfirm(true)}
        >
          Delete
        </button>
      </div>

      {showDeleteConfirm && (
        <div className={styles.confirmPopup}>
          <p>Are you sure you want to delete this user?</p>
          <button className={styles.confirmButton} onClick={handleDelete}>
            Yes, Delete
          </button>
          <button
            className={styles.cancelButton}
            onClick={() => setShowDeleteConfirm(false)}
          >
            Cancel
          </button>
        </div>
      )}
    </div>
  );


  return (
    <div>
      <p>User details for user:</p>
      <p>personId</p>
    </div>
  );
};

export default EditUserDetails;
